Enum syntax::ast::AttrStyleUnstable
[-] [+]
[src]
pub enum AttrStyle {
AttrOuter,
AttrInner,
}Distinguishes between Attributes that decorate items and Attributes that are contained as statements within items. These two cases need to be distinguished for pretty-printing.
Variants
AttrOuter | |
AttrInner |