Enum syntax::ast::MutabilityUnstable
[-] [+]
[src]
pub enum Mutability {
MutMutable,
MutImmutable,
}Variants
MutMutable | |
MutImmutable |
pub enum Mutability {
MutMutable,
MutImmutable,
}MutMutable | |
MutImmutable |
impl Copy for Mutabilityimpl Debug for Mutabilityimpl Hash for Mutabilityfn hash<__H: Hasher>(&self, __arg_0: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasherimpl Decodable for Mutabilityfn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<Mutability, __D>impl Encodable for Mutabilityimpl Eq for Mutabilityimpl PartialEq for Mutabilityfn eq(&self, __arg_0: &Mutability) -> boolfn ne(&self, __arg_0: &Mutability) -> boolimpl Clone for Mutabilityfn clone(&self) -> Mutabilityfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).