Enum syntax::ast::SignUnstable
[-] [+]
[src]
pub enum Sign {
Minus,
Plus,
}Variants
Minus | |
Plus |
pub enum Sign {
Minus,
Plus,
}Minus | |
Plus |
impl Signimpl Copy for Signimpl Debug for Signimpl Hash for Signfn hash<__H: Hasher>(&self, __arg_0: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasherimpl Decodable for Signimpl Encodable for Signimpl Eq for Signimpl PartialEq for Signimpl Clone for Signfn clone(&self) -> Signfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).