Enum syntax::ast::UnsafetyUnstable
[-] [+]
[src]
pub enum Unsafety {
Unsafe,
Normal,
}Variants
Unsafe | |
Normal |
pub enum Unsafety {
Unsafe,
Normal,
}Unsafe | |
Normal |
impl Display for Unsafetyimpl Debug for Unsafetyimpl Hash for Unsafetyfn hash<__H: Hasher>(&self, __arg_0: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasherimpl Decodable for Unsafetyimpl Encodable for Unsafetyimpl Eq for Unsafetyimpl PartialEq for Unsafetyimpl Clone for Unsafetyfn clone(&self) -> Unsafetyfn clone_from(&mut self, source: &Self)impl Copy for Unsafety
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).