Struct syntax::ast::ArgUnstable
[-] [+]
[src]
pub struct Arg {
pub ty: P<Ty>,
pub pat: P<Pat>,
pub id: NodeId,
}represents an argument in a function header
Fields
ty | |
pat | |
id |
pub struct Arg {
pub ty: P<Ty>,
pub pat: P<Pat>,
pub id: NodeId,
}represents an argument in a function header
ty | |
pat | |
id |
impl Argfn new_self(span: Span, mutability: Mutability, self_ident: Ident) -> Argimpl ToSource for Argimpl ToTokens for Argimpl Debug for Argimpl Hash for Argfn hash<__H: Hasher>(&self, __arg_0: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasherimpl Decodable for Argimpl Encodable for Argimpl Eq for Argimpl PartialEq for Argimpl Clone for Argfn clone(&self) -> Argfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).