Struct syntax::ast::ExprUnstable
[-] [+]
[src]
pub struct Expr {
pub id: NodeId,
pub node: Expr_,
pub span: Span,
}An expression
Fields
id | |
node | |
span |
pub struct Expr {
pub id: NodeId,
pub node: Expr_,
pub span: Span,
}An expression
id | |
node | |
span |
impl MaybeFnLike for Exprfn is_fn_like(&self) -> boolimpl Debug for Exprimpl Hash for Exprfn hash<__H: Hasher>(&self, __arg_0: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasherimpl Decodable for Exprimpl Encodable for Exprimpl Eq for Exprimpl PartialEq for Exprimpl Clone for Exprfn clone(&self) -> Exprfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).