Struct syntax::ast::FieldUnstable
[-] [+]
[src]
pub struct Field {
pub ident: SpannedIdent,
pub expr: P<Expr>,
pub span: Span,
}Fields
ident | |
expr | |
span |
pub struct Field {
pub ident: SpannedIdent,
pub expr: P<Expr>,
pub span: Span,
}ident | |
expr | |
span |
impl Debug for Fieldimpl Hash for Fieldfn hash<__H: Hasher>(&self, __arg_0: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasherimpl Decodable for Fieldimpl Encodable for Fieldimpl Eq for Fieldimpl PartialEq for Fieldimpl Clone for Fieldfn clone(&self) -> Fieldfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).