Struct syntax::ast::NameUnstable
[-] [+]
[src]
pub struct Name(pub u32);
A name is a part of an identifier, representing a string or gensym. It's the result of interning.
pub struct Name(pub u32);
A name is a part of an identifier, representing a string or gensym. It's the result of interning.
impl Nameimpl Debug for Nameimpl Display for Nameimpl Copy for Nameimpl Clone for Namefn clone(&self) -> Namefn clone_from(&mut self, source: &Self)impl Decodable for Nameimpl Encodable for Nameimpl Hash for Namefn hash<__H: Hasher>(&self, __arg_0: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasherimpl PartialOrd for Namefn partial_cmp(&self, __arg_0: &Name) -> Option<Ordering>fn lt(&self, __arg_0: &Name) -> boolfn le(&self, __arg_0: &Name) -> boolfn gt(&self, __arg_0: &Name) -> boolfn ge(&self, __arg_0: &Name) -> boolimpl PartialEq for Nameimpl Ord for Nameimpl Eq for Name
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).