Struct syntax::ast::PatUnstable
[-] [+]
[src]
pub struct Pat {
pub id: NodeId,
pub node: Pat_,
pub span: Span,
}Fields
id | |
node | |
span |
pub struct Pat {
pub id: NodeId,
pub node: Pat_,
pub span: Span,
}id | |
node | |
span |
impl Debug for Patimpl Hash for Patfn hash<__H: Hasher>(&self, __arg_0: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasherimpl Decodable for Patimpl Encodable for Patimpl Eq for Patimpl PartialEq for Patimpl Clone for Patfn clone(&self) -> Patfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).