Struct syntax::ast::TyUnstable
[-] [+]
[src]
pub struct Ty {
pub id: NodeId,
pub node: Ty_,
pub span: Span,
}Fields
id | |
node | |
span |
pub struct Ty {
pub id: NodeId,
pub node: Ty_,
pub span: Span,
}id | |
node | |
span |
impl ToSource for Tyimpl ToTokens for Tyimpl Debug for Tyimpl Hash for Tyfn hash<__H: Hasher>(&self, __arg_0: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasherimpl Decodable for Tyimpl Encodable for Tyimpl Eq for Tyimpl PartialEq for Tyimpl Clone for Tyfn clone(&self) -> Tyfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).